@@ -8,18 +8,21 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"slices"
 	"strconv"
 	"strings"
 	"testing"
 
 	"github.com/aws/aws-sdk-go-v2/aws"
+	cfn "github.com/aws/aws-sdk-go-v2/service/cloudformation"
+	cfntypes "github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
 	awseks "github.com/aws/aws-sdk-go-v2/service/eks"
 	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
-	"k8s.io/utils/strings/slices"
+	k8sslices "k8s.io/utils/strings/slices"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
@@ -29,6 +32,7 @@ import (
 	. "github.com/weaveworks/eksctl/integration/runner"
 	"github.com/weaveworks/eksctl/integration/tests"
 	clusterutils "github.com/weaveworks/eksctl/integration/utilities/cluster"
+	"github.com/weaveworks/eksctl/pkg/actions/podidentityassociation"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/eks"
 	kubewrapper "github.com/weaveworks/eksctl/pkg/kubernetes"
@@ -36,8 +40,9 @@ import (
 )
 
 var (
-	params    *tests.Params
-	rawClient *kubewrapper.RawClient
+	params      *tests.Params
+	rawClient   *kubewrapper.RawClient
+	awsProvider api.ClusterProvider
 )
 
 func init() {
@@ -125,35 +130,6 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 				return cmd
 			}, "5m", "30s").Should(RunSuccessfullyWithOutputStringLines(ContainElement(ContainSubstring("ACTIVE"))))
 
-			By("successfully creating the aws-ebs-csi-driver addon via config file")
-			// setup config file
-			clusterConfig := getInitialClusterConfig()
-			clusterConfig.Addons = append(clusterConfig.Addons, &api.Addon{
-				Name: api.AWSEBSCSIDriverAddon,
-			})
-			data, err := json.Marshal(clusterConfig)
-
-			Expect(err).NotTo(HaveOccurred())
-			cmd = params.EksctlCreateCmd.
-				WithArgs(
-					"addon",
-					"--config-file", "-",
-				).
-				WithoutArg("--region", params.Region).
-				WithStdin(bytes.NewReader(data))
-			Expect(cmd).To(RunSuccessfully())
-
-			Eventually(func() runner.Cmd {
-				cmd := params.EksctlGetCmd.
-					WithArgs(
-						"addon",
-						"--name", api.AWSEBSCSIDriverAddon,
-						"--cluster", clusterName,
-						"--verbose", "2",
-					)
-				return cmd
-			}, "10m", "30s").Should(RunSuccessfullyWithOutputStringLines(ContainElement(ContainSubstring("ACTIVE"))))
-
 			By("Deleting the kube-proxy addon")
 			cmd = params.EksctlDeleteCmd.
 				WithArgs(
@@ -164,16 +140,6 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 				)
 			Expect(cmd).To(RunSuccessfully())
 
-			By("Deleting the aws-ebs-csi-driver addon")
-			cmd = params.EksctlDeleteCmd.
-				WithArgs(
-					"addon",
-					"--name", api.AWSEBSCSIDriverAddon,
-					"--cluster", clusterName,
-					"--verbose", "2",
-				)
-			Expect(cmd).To(RunSuccessfully())
-
 			By("Deleting the vpc-cni addon with --preserve")
 			cmd = params.EksctlDeleteCmd.
 				WithArgs(
@@ -184,8 +150,7 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 					"--verbose", "2",
 				)
 			Expect(cmd).To(RunSuccessfully())
-
-			_, err = rawClient.ClientSet().AppsV1().DaemonSets("kube-system").Get(context.Background(), "aws-node", metav1.GetOptions{})
+			_, err := rawClient.ClientSet().AppsV1().DaemonSets("kube-system").Get(context.Background(), "aws-node", metav1.GetOptions{})
 			Expect(err).NotTo(HaveOccurred())
 		})
 
@@ -532,6 +497,234 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 		))
 	})
 
+	Context("configure IAM permissions via pod identity associations or IRSA", Ordered, func() {
+		const (
+			pollInterval       = 10  //seconds
+			timeOutSeconds     = 600 // 10 minutes
+			awsNodeSA          = "aws-node"
+			ebsCSIControllerSA = "ebs-csi-controller-sa"
+			efsCSIControllerSA = "efs-csi-controller-sa"
+		)
+
+		clusterConfig := getInitialClusterConfig()
+		cfg := NewConfig(clusterConfig.Metadata.Region)
+		makeIRSAStackName := func(addonName string) string {
+			return fmt.Sprintf("eksctl-%s-addon-%s", clusterConfig.Metadata.Name, addonName)
+		}
+		makePodIDStackName := func(addonName, serviceAccountName string) string {
+			return podidentityassociation.MakeAddonPodIdentityStackName(clusterConfig.Metadata.Name, addonName, serviceAccountName)
+		}
+		makeCreateAddonCMD := func() runner.Cmd {
+			return params.EksctlCreateCmd.
+				WithArgs("addon").
+				WithArgs("--config-file", "-").
+				WithoutArg("--region", params.Region).
+				WithStdin(clusterutils.Reader(clusterConfig))
+		}
+		makeUpdateAddonCMD := func(args ...string) runner.Cmd {
+			cmd := params.EksctlUpdateCmd.
+				WithArgs("addon").
+				WithArgs("--config-file", "-").
+				WithoutArg("--region", params.Region).
+				WithStdin(clusterutils.Reader(clusterConfig))
+			if len(args) > 0 {
+				return cmd.WithArgs(args...)
+			}
+			return cmd
+		}
+		makeDeleteAddonCMD := func(addonName string, args ...string) runner.Cmd {
+			cmd := params.EksctlDeleteCmd.WithArgs(
+				"addon",
+				"--cluster", clusterConfig.Metadata.Name,
+				"--name", addonName,
+			)
+			if len(args) > 0 {
+				return cmd.WithArgs(args...)
+			}
+			return cmd
+		}
+		assertStackExists := func(stackName string) {
+			Expect(cfg).To(HaveExistingStack(stackName))
+		}
+		assertStackNotExists := func(stackName string) {
+			Expect(cfg).NotTo(HaveExistingStack(stackName))
+		}
+		assertStackDeleted := func(stackName string) {
+			Eventually(cfg, timeOutSeconds, pollInterval).ShouldNot(HaveExistingStack(stackName))
+		}
+		assertPodIDPresence := func(namespace, serviceAccountName string, expectPodIDExists bool) {
+			cmd := params.EksctlGetCmd.WithArgs(
+				"podidentityassociation",
+				"--cluster", clusterConfig.Metadata.Name,
+				"--namespace", namespace,
+				"--service-account-name", serviceAccountName,
+			)
+			matcher := ContainElement("No podidentityassociations found")
+			if expectPodIDExists {
+				matcher = ContainElements(
+					ContainSubstring(namespace),
+					ContainSubstring(serviceAccountName),
+				)
+				cmd = cmd.WithArgs("--output", "json")
+			}
+			Expect(cmd).To(RunSuccessfullyWithOutputStringLines(matcher))
+		}
+		assertAddonHasPodIDs := func(addonName string, podIDsCount int) {
+			addon, err := awsProvider.EKS().DescribeAddon(context.Background(), &awseks.DescribeAddonInput{
+				AddonName:   aws.String(addonName),
+				ClusterName: aws.String(clusterConfig.Metadata.Name),
+			})
+			ExpectWithOffset(1, err).NotTo(HaveOccurred())
+			ExpectWithOffset(1, addon.Addon.PodIdentityAssociations).To(HaveLen(podIDsCount))
+		}
+
+		BeforeAll(func() {
+			clusterConfig.Addons = []*api.Addon{{Name: api.PodIdentityAgentAddon}}
+			Expect(makeCreateAddonCMD()).To(RunSuccessfully())
+		})
+
+		It("should provide IAM permissions when creating addons", func() {
+
+			By("creating pod identity associations for addons when explicitly set by user")
+			clusterConfig.Addons = []*api.Addon{
+				{
+					Name: api.VPCCNIAddon,
+					PodIdentityAssociations: &[]api.PodIdentityAssociation{
+						{
+							Namespace:            "kube-system",
+							ServiceAccountName:   awsNodeSA,
+							PermissionPolicyARNs: []string{"arn:aws:iam::aws:policy/AmazonEKS_CNI_Policy"},
+						},
+					},
+				},
+			}
+			Expect(makeCreateAddonCMD()).To(RunSuccessfully())
+			assertAddonHasPodIDs(api.VPCCNIAddon, 1)
+			assertStackExists(makePodIDStackName(api.VPCCNIAddon, awsNodeSA))
+
+			By("creating pod identity associations for addons when `autoApplyPodIdentityAssociations: true` and addon supports podIDs")
+			clusterConfig.AddonsConfig.AutoApplyPodIdentityAssociations = true
+			clusterConfig.Addons = []*api.Addon{{Name: api.AWSEBSCSIDriverAddon}}
+			Expect(makeCreateAddonCMD()).To(RunSuccessfully())
+			assertAddonHasPodIDs(api.AWSEBSCSIDriverAddon, 1)
+			assertStackExists(makePodIDStackName(api.AWSEBSCSIDriverAddon, ebsCSIControllerSA))
+			assertStackNotExists(makeIRSAStackName(api.AWSEBSCSIDriverAddon))
+
+			By("falling back to IRSA when `autoApplyPodIdentityAssociations: true` but addon doesn't support podIDs")
+			clusterConfig.Addons = []*api.Addon{{Name: api.AWSEFSCSIDriverAddon}}
+			Expect(makeCreateAddonCMD()).To(RunSuccessfully())
+			assertAddonHasPodIDs(api.AWSEFSCSIDriverAddon, 0)
+			assertStackNotExists(makePodIDStackName(api.AWSEFSCSIDriverAddon, efsCSIControllerSA))
+			assertStackExists(makeIRSAStackName(api.AWSEFSCSIDriverAddon))
+		})
+
+		It("should remove IAM permissions when deleting addons", func() {
+
+			By("deleting pod identity associations and IAM role when deleting addon")
+			Expect(makeDeleteAddonCMD(api.VPCCNIAddon)).To(RunSuccessfully())
+			assertPodIDPresence("kube-system", awsNodeSA, false)
+			assertStackDeleted(makeIRSAStackName(api.VPCCNIAddon))
+			assertStackDeleted(makePodIDStackName(api.VPCCNIAddon, awsNodeSA))
+
+			By("keeping pod identity associations and IAM role when deleting addon with preserve")
+			Expect(makeDeleteAddonCMD(api.AWSEBSCSIDriverAddon, "--preserve")).To(RunSuccessfully())
+			assertPodIDPresence("kube-system", ebsCSIControllerSA, true)
+			assertStackExists(makePodIDStackName(api.AWSEBSCSIDriverAddon, ebsCSIControllerSA))
+
+			By("cleaning up IAM role on subsequent deletion")
+			Expect(makeDeleteAddonCMD(api.AWSEBSCSIDriverAddon)).To(RunSuccessfully())
+			assertStackDeleted(makePodIDStackName(api.AWSEBSCSIDriverAddon, ebsCSIControllerSA))
+			// now manually cleanup the pod ID to not conflict with subsequent tests
+			Expect(params.EksctlDeleteCmd.
+				WithArgs(
+					"podidentityassociation",
+					"--cluster", clusterConfig.Metadata.Name,
+					"--namespace", "kube-system",
+					"--service-account-name", ebsCSIControllerSA,
+				)).
+				To(RunSuccessfully())
+			assertPodIDPresence("kube-system", ebsCSIControllerSA, false)
+
+			By("deleting IRSA when deleting addons")
+			Expect(makeDeleteAddonCMD(api.AWSEFSCSIDriverAddon)).To(RunSuccessfully())
+			assertPodIDPresence("kube-system", efsCSIControllerSA, false)
+			assertStackDeleted(makeIRSAStackName(api.AWSEFSCSIDriverAddon))
+		})
+
+		It("should update IAM permissions when updating or migrating addons", func() {
+			clusterConfig.AddonsConfig.AutoApplyPodIdentityAssociations = false
+			clusterConfig.Addons = []*api.Addon{
+				{Name: api.VPCCNIAddon},
+				{Name: api.AWSEBSCSIDriverAddon},
+			}
+
+			By("creating addons with IRSA")
+			Expect(makeCreateAddonCMD()).To(RunSuccessfully())
+			assertAddonHasPodIDs(api.VPCCNIAddon, 0)
+			assertAddonHasPodIDs(api.AWSEBSCSIDriverAddon, 0)
+			assertStackExists(makeIRSAStackName(api.VPCCNIAddon))
+			assertStackExists(makeIRSAStackName(api.AWSEBSCSIDriverAddon))
+			assertStackNotExists(makePodIDStackName(api.VPCCNIAddon, awsNodeSA))
+			assertStackNotExists(makePodIDStackName(api.AWSEBSCSIDriverAddon, ebsCSIControllerSA))
+
+			By("updating the addon to use pod identity")
+			clusterConfig.Addons[1].PodIdentityAssociations = &[]api.PodIdentityAssociation{
+				{
+					Namespace:            "kube-system",
+					ServiceAccountName:   ebsCSIControllerSA,
+					PermissionPolicyARNs: []string{"arn:aws:iam::aws:policy/service-role/AmazonEBSCSIDriverPolicy"},
+				},
+			}
+			Expect(makeUpdateAddonCMD()).To(RunSuccessfullyWithOutputStringLines(
+				ContainElement(ContainSubstring("deleting old IRSA stack for addon %s", api.AWSEBSCSIDriverAddon)),
+				ContainElement(ContainSubstring("will delete stack %q", makeIRSAStackName(api.AWSEBSCSIDriverAddon))),
+			))
+			assertAddonHasPodIDs(api.AWSEBSCSIDriverAddon, 1)
+			assertStackNotExists(makeIRSAStackName(api.AWSEBSCSIDriverAddon))
+
+			By("ensuring that updating addon again works")
+			Expect(makeUpdateAddonCMD()).To(RunSuccessfullyWithOutputStringLines(
+				Not(ContainElement(ContainSubstring("deleting old IRSA stack for addon %s", api.AWSEBSCSIDriverAddon))),
+			))
+
+			By("failing to update addon with pod identity if the field is unset")
+			clusterConfig.Addons[1].PodIdentityAssociations = nil
+			session := makeUpdateAddonCMD().Run()
+			Expect(session.ExitCode()).To(Equal(1))
+			Expect(string(session.Err.Contents())).To(ContainSubstring("addon %s has pod identity associations,"+
+				" to remove pod identity associations from an addon, addon.podIdentityAssociations must be explicitly set to []; "+
+				"if the addon was migrated to use pod identity, addon.podIdentityAssociations must be set to values obtained from "+
+				"`aws eks describe-pod-identity-association --cluster-name=%s", api.AWSEBSCSIDriverAddon, clusterConfig.Metadata.Name))
+
+			By("removing all pod identity associations owned by the addon")
+			clusterConfig.Addons[1].PodIdentityAssociations = &[]api.PodIdentityAssociation{}
+			Expect(makeUpdateAddonCMD()).To(RunSuccessfully())
+			assertAddonHasPodIDs(api.AWSEBSCSIDriverAddon, 0)
+
+			By("migrating an addon to pod identity using the utils command")
+			Expect(params.EksctlUtilsCmd.
+				WithArgs(
+					"migrate-to-pod-identity",
+					"--cluster", clusterConfig.Metadata.Name,
+					"--approve",
+				)).To(RunSuccessfully())
+			assertAddonHasPodIDs(api.VPCCNIAddon, 1)
+			// assert IRSA stack still exists, but tags reflect association with podID
+			stackHasTag := func(stack cfntypes.Stack, tag string) bool {
+				return slices.ContainsFunc(stack.Tags, func(t cfntypes.Tag) bool {
+					return *t.Key == tag
+				})
+			}
+			describeStackOutput, err := awsProvider.CloudFormation().DescribeStacks(context.Background(), &cfn.DescribeStacksInput{
+				StackName: aws.String(makeIRSAStackName(api.VPCCNIAddon)),
+			})
+			Expect(err).NotTo(HaveOccurred())
+			Expect(describeStackOutput.Stacks).To(HaveLen(1))
+			Expect(stackHasTag(describeStackOutput.Stacks[0], api.IAMServiceAccountNameTag)).To(BeFalse())
+			Expect(stackHasTag(describeStackOutput.Stacks[0], api.PodIdentityAssociationNameTag)).To(BeTrue())
+		})
+	})
+
 	Context("addons in a cluster with no nodes", func() {
 		var clusterConfig *api.ClusterConfig
 
@@ -638,6 +831,7 @@ var _ = Describe("(Integration) [EKS Addons test]", func() {
 var _ = AfterSuite(func() {
 	cmd := params.EksctlDeleteCmd.WithArgs(
 		"cluster", params.ClusterName,
+		"--disable-nodegroup-eviction",
 		"--verbose", "2",
 	)
 	Expect(cmd).To(RunSuccessfully())
@@ -657,6 +851,7 @@ func getRawClient(ctx context.Context, clusterName string) *kubewrapper.RawClien
 	Expect(err).ShouldNot(HaveOccurred())
 	rawClient, err := ctl.NewRawClient(cfg)
 	Expect(err).NotTo(HaveOccurred())
+	awsProvider = ctl.AWSProvider
 	return rawClient
 }
 
@@ -683,8 +878,8 @@ func getInitialClusterConfig() *api.ClusterConfig {
 	return clusterConfig
 }
 
-func getConfigMap(clientset kubernetes.Interface, name string) *corev1.ConfigMap {
-	configMap, err := clientset.CoreV1().ConfigMaps("kube-system").Get(context.Background(), "coredns", metav1.GetOptions{})
+func getConfigMap(clientset kubernetes.Interface, addonName string) *corev1.ConfigMap {
+	configMap, err := clientset.CoreV1().ConfigMaps("kube-system").Get(context.Background(), addonName, metav1.GetOptions{})
 	Expect(err).NotTo(HaveOccurred())
 	return configMap
 }
@@ -700,7 +895,7 @@ func getCacheValue(configMap *corev1.ConfigMap) string {
 	Expect(ok).To(BeTrue())
 
 	coreFileValues := strings.Fields(strings.Replace(coreFile, "\n", " ", -1))
-	return coreFileValues[slices.Index(coreFileValues, "cache")+1]
+	return coreFileValues[k8sslices.Index(coreFileValues, "cache")+1]
 }
 
 func updateCacheValue(configMap *corev1.ConfigMap, currentValue string, newValue string) {
