@@ -246,7 +246,7 @@ var _ = Describe("Delete", func() {
 				})
 
 				mockedDrainInput := &nodegroup.DrainInput{
-					NodeGroups:     cmdutils.ToKubeNodeGroups(cfg),
+					NodeGroups:     cmdutils.ToKubeNodeGroups(cfg.NodeGroups, cfg.ManagedNodeGroups),
 					MaxGracePeriod: ctl.AWSProvider.WaitTimeout(),
 					Parallel:       1,
 				}
@@ -348,7 +348,7 @@ var _ = Describe("Delete", func() {
 					},
 				}
 				mockedDrainInput := &nodegroup.DrainInput{
-					NodeGroups:     cmdutils.ToKubeNodeGroups(cfg),
+					NodeGroups:     cmdutils.ToKubeNodeGroups(cfg.NodeGroups, cfg.ManagedNodeGroups),
 					MaxGracePeriod: ctl.AWSProvider.WaitTimeout(),
 					Parallel:       1,
 				}
